@@ -159,6 +159,7 @@ var _ = Describe("CSIClonePhase test", func() {
 			Expect(pvc.Spec.Resources.Requests[corev1.ResourceStorage]).
 				To(Equal(sourceClaim.Status.Capacity[corev1.ResourceStorage]))
 			Expect(pvc.Labels[p.OwnershipLabel]).To(Equal("uid"))
+			Expect(pvc.Labels[cc.LabelExcludeFromVeleroBackup]).To(Equal("true"))
 		})
 
 		Context("with desired claim created", func() {
@@ -177,6 +178,7 @@ var _ = Describe("CSIClonePhase test", func() {
 			It("should succeed (immediate bind)", func() {
 				desired := getDesiredClaim()
 				desired.Spec.VolumeName = "vol"
+				desired.Status.Phase = corev1.ClaimBound
 				p := createCSIClonePhase(sourceClaim, getStorageClass(), desired)
 
 				result, err := p.Reconcile(context.Background())
