@@ -328,6 +328,9 @@ const (
 	//nolint:gosec // These are not credentials
 	LabelDynamicCredentialSupport = "kubevirt.io/dynamic-credentials-support"
 
+	// LabelExcludeFromVeleroBackup provides a const to indicate whether an object should be excluded from velero backup
+	LabelExcludeFromVeleroBackup = "velero.io/exclude-from-backup"
+
 	// ProgressDone this means we are DONE
 	ProgressDone = "100.0%"
 
@@ -1525,7 +1528,7 @@ func InflateSizeWithOverhead(ctx context.Context, c client.Client, imgSize int64
 
 // IsBound returns if the pvc is bound
 func IsBound(pvc *corev1.PersistentVolumeClaim) bool {
-	return pvc.Spec.VolumeName != ""
+	return pvc != nil && pvc.Status.Phase == corev1.ClaimBound
 }
 
 // IsUnbound returns if the pvc is not bound yet
@@ -1533,6 +1536,11 @@ func IsUnbound(pvc *corev1.PersistentVolumeClaim) bool {
 	return !IsBound(pvc)
 }
 
+// IsLost returns if the pvc is lost
+func IsLost(pvc *corev1.PersistentVolumeClaim) bool {
+	return pvc != nil && pvc.Status.Phase == corev1.ClaimLost
+}
+
 // IsImageStream returns true if registry source is ImageStream
 func IsImageStream(pvc *corev1.PersistentVolumeClaim) bool {
 	return pvc.Annotations[AnnRegistryImageStream] == "true"
