@@ -18,6 +18,7 @@ package datavolume
 
 import (
 	"context"
+	"fmt"
 	"reflect"
 	"strings"
 	"time"
@@ -26,6 +27,7 @@ import (
 	. "github.com/onsi/gomega"
 
 	snapshotv1 "github.com/kubernetes-csi/external-snapshotter/client/v6/apis/volumesnapshot/v1"
+
 	corev1 "k8s.io/api/core/v1"
 	storagev1 "k8s.io/api/storage/v1"
 	extv1 "k8s.io/apiextensions-apiserver/pkg/apis/apiextensions/v1"
@@ -36,6 +38,7 @@ import (
 	"k8s.io/client-go/kubernetes/scheme"
 	"k8s.io/client-go/tools/record"
 	"k8s.io/utils/ptr"
+
 	"sigs.k8s.io/controller-runtime/pkg/client"
 	"sigs.k8s.io/controller-runtime/pkg/client/fake"
 	logf "sigs.k8s.io/controller-runtime/pkg/log"
@@ -419,6 +422,235 @@ var _ = Describe("All DataVolume Tests", func() {
 		})
 	})
 
+	var _ = Describe("validateContentTypes", func() {
+		getContentType := func(contentType string) cdiv1.DataVolumeContentType {
+			if contentType == "" {
+				return cdiv1.DataVolumeKubeVirt
+			}
+			return cdiv1.DataVolumeContentType(contentType)
+		}
+
+		DescribeTable("should return", func(sourceContentType, targetContentType string, expectedResult bool) {
+			sourcePvc := CreatePvc("testPVC", "default", map[string]string{AnnContentType: sourceContentType}, nil)
+			dvSpec := &cdiv1.DataVolumeSpec{}
+			dvSpec.ContentType = cdiv1.DataVolumeContentType(targetContentType)
+
+			validated, sourceContent, targetContent := validateContentTypes(sourcePvc, dvSpec)
+			Expect(validated).To(Equal(expectedResult))
+			Expect(sourceContent).To(Equal(getContentType(sourceContentType)))
+			Expect(targetContent).To(Equal(getContentType(targetContentType)))
+		},
+			Entry("true when using archive in source and target", string(cdiv1.DataVolumeArchive), string(cdiv1.DataVolumeArchive), true),
+			Entry("false when using archive in source and KubeVirt in target", string(cdiv1.DataVolumeArchive), string(cdiv1.DataVolumeKubeVirt), false),
+			Entry("false when using KubeVirt in source and archive in target", string(cdiv1.DataVolumeKubeVirt), string(cdiv1.DataVolumeArchive), false),
+			Entry("true when using KubeVirt in source and target", string(cdiv1.DataVolumeKubeVirt), string(cdiv1.DataVolumeKubeVirt), true),
+			Entry("true when using default in source and target", "", "", true),
+			Entry("true when using default in source and KubeVirt (explicit) in target", "", string(cdiv1.DataVolumeKubeVirt), true),
+			Entry("true when using KubeVirt (explicit) in source and default in target", string(cdiv1.DataVolumeKubeVirt), "", true),
+			Entry("false when using default in source and archive in target", "", string(cdiv1.DataVolumeArchive), false),
+			Entry("false when using archive in source and default in target", string(cdiv1.DataVolumeArchive), "", false),
+		)
+	})
+
+	var _ = Describe("validateClone", func() {
+		sourcePvc := CreatePvc("testPVC", "default", map[string]string{}, nil)
+		blockVM := corev1.PersistentVolumeBlock
+		fsVM := corev1.PersistentVolumeFilesystem
+
+		It("Should reject the clone if source and target have different content types", func() {
+			sourcePvc.Annotations[AnnContentType] = string(cdiv1.DataVolumeKubeVirt)
+			dvSpec := &cdiv1.DataVolumeSpec{ContentType: cdiv1.DataVolumeArchive}
+
+			err := validateClone(sourcePvc, dvSpec)
+			Expect(err).To(HaveOccurred())
+			Expect(err.Error()).To(ContainSubstring(
+				fmt.Sprintf("Source contentType (%s) and target contentType (%s) do not match", cdiv1.DataVolumeKubeVirt, cdiv1.DataVolumeArchive)))
+		})
+
+		It("Should reject the clone if the target has an incompatible size and the source PVC is using block volumeMode (Storage API)", func() {
+			sourcePvc.Annotations[AnnContentType] = string(cdiv1.DataVolumeKubeVirt)
+			sourcePvc.Spec.VolumeMode = &blockVM
+			storageSpec := &cdiv1.StorageSpec{
+				Resources: corev1.VolumeResourceRequirements{
+					Requests: corev1.ResourceList{
+						corev1.ResourceStorage: resource.MustParse("1Mi"), // Less than the source's one (1Gi)
+					},
+				},
+			}
+			dvSpec := &cdiv1.DataVolumeSpec{Storage: storageSpec}
+
+			err := validateClone(sourcePvc, dvSpec)
+			Expect(err).To(HaveOccurred())
+			Expect(err.Error()).To(ContainSubstring("target resources requests storage size is smaller than the source"))
+		})
+
+		It("Should validate the clone when source PVC is using fs volumeMode, even if the target has an incompatible size (Storage API)", func() {
+			sourcePvc.Annotations[AnnContentType] = string(cdiv1.DataVolumeKubeVirt)
+			sourcePvc.Spec.VolumeMode = &fsVM
+			storageSpec := &cdiv1.StorageSpec{
+				Resources: corev1.VolumeResourceRequirements{
+					Requests: corev1.ResourceList{
+						corev1.ResourceStorage: resource.MustParse("1Mi"), // Less than the source's one (1Gi)
+					},
+				},
+			}
+			dvSpec := &cdiv1.DataVolumeSpec{Storage: storageSpec}
+
+			err := validateClone(sourcePvc, dvSpec)
+			Expect(err).ToNot(HaveOccurred())
+		})
+
+		It("Should validate the clone if target's size is empty, even when the source uses block volumeMode (Storage API)", func() {
+			sourcePvc.Annotations[AnnContentType] = string(cdiv1.DataVolumeKubeVirt)
+			sourcePvc.Spec.VolumeMode = &blockVM
+			storageSpec := &cdiv1.StorageSpec{}
+			dvSpec := &cdiv1.DataVolumeSpec{Storage: storageSpec}
+
+			err := validateClone(sourcePvc, dvSpec)
+			Expect(err).ToNot(HaveOccurred())
+		})
+
+		It("Should reject the clone when the target has an incompatible size (PVC API)", func() {
+			sourcePvc.Annotations[AnnContentType] = string(cdiv1.DataVolumeKubeVirt)
+			pvcSpec := &corev1.PersistentVolumeClaimSpec{
+				Resources: corev1.VolumeResourceRequirements{
+					Requests: corev1.ResourceList{
+						corev1.ResourceStorage: resource.MustParse("1Mi"), // Less than the source's one (1Gi)
+					},
+				},
+			}
+			dvSpec := &cdiv1.DataVolumeSpec{PVC: pvcSpec}
+
+			err := validateClone(sourcePvc, dvSpec)
+			Expect(err).To(HaveOccurred())
+			Expect(err.Error()).To(ContainSubstring("target resources requests storage size is smaller than the source"))
+
+		})
+
+		It("Should validate the clone when both sizes are compatible (PVC API)", func() {
+			sourcePvc.Annotations[AnnContentType] = string(cdiv1.DataVolumeKubeVirt)
+			pvcSpec := &corev1.PersistentVolumeClaimSpec{
+				Resources: corev1.VolumeResourceRequirements{
+					Requests: corev1.ResourceList{
+						corev1.ResourceStorage: resource.MustParse("1Gi"), // Same as the source's
+					},
+				},
+			}
+			dvSpec := &cdiv1.DataVolumeSpec{PVC: pvcSpec}
+
+			err := validateClone(sourcePvc, dvSpec)
+			Expect(err).ToNot(HaveOccurred())
+		})
+	})
+
+	var _ = Describe("validateCloneAndSourcePVC", func() {
+		scName := "testsc"
+		sc := CreateStorageClassWithProvisioner(scName, map[string]string{
+			AnnDefaultStorageClass: "true",
+		}, map[string]string{}, "csi-plugin")
+
+		syncState := func(dv *cdiv1.DataVolume) *dvSyncState {
+			return &dvSyncState{dv: dv, dvMutated: dv.DeepCopy()}
+		}
+
+		DescribeTable("Validation mechanism rejects or accepts the clone depending on the contentType combination",
+			func(sourceContentType, targetContentType string, expectedResult bool) {
+				dv := newCloneDataVolume("test-dv")
+				dv.Spec.ContentType = cdiv1.DataVolumeContentType(targetContentType)
+				storageProfile := createStorageProfile(scName, nil, FilesystemMode)
+				reconciler = createCloneReconciler(dv, storageProfile, sc)
+
+				done, err := reconciler.validateCloneAndSourcePVC(syncState(dv), reconciler.log)
+				Expect(err).ToNot(HaveOccurred())
+				Expect(done).To(BeFalse())
+
+				// We create the source PVC after creating the clone
+				pvc := CreatePvcInStorageClass("test", metav1.NamespaceDefault, &scName, map[string]string{
+					AnnContentType: sourceContentType}, nil, corev1.ClaimBound)
+				err = reconciler.client.Create(context.TODO(), pvc)
+				Expect(err).ToNot(HaveOccurred())
+
+				syncRes := syncState(dv)
+				done, err = reconciler.validateCloneAndSourcePVC(syncRes, reconciler.log)
+				Expect(done).To(Equal(expectedResult))
+				Expect(err).ToNot(HaveOccurred())
+				if expectedResult == false {
+					Expect(syncRes.phaseSync.event.reason).To(Equal(CloneValidationFailed))
+				} else {
+					Expect(syncRes.phaseSync).To(BeNil())
+				}
+			},
+			Entry("Archive in source and target", string(cdiv1.DataVolumeArchive), string(cdiv1.DataVolumeArchive), true),
+			Entry("Archive in source and KubeVirt in target", string(cdiv1.DataVolumeArchive), string(cdiv1.DataVolumeKubeVirt), false),
+			Entry("KubeVirt in source and archive in target", string(cdiv1.DataVolumeKubeVirt), string(cdiv1.DataVolumeArchive), false),
+			Entry("KubeVirt in source and target", string(cdiv1.DataVolumeKubeVirt), string(cdiv1.DataVolumeKubeVirt), true),
+			Entry("Empty (KubeVirt by default) in source and target", "", "", true),
+			Entry("Empty (KubeVirt by default) in source and KubeVirt (explicit) in target", "", string(cdiv1.DataVolumeKubeVirt), true),
+			Entry("KubeVirt (explicit) in source and empty (KubeVirt by default) in target", string(cdiv1.DataVolumeKubeVirt), "", true),
+			Entry("Empty (kubeVirt by default) in source and archive in target", "", string(cdiv1.DataVolumeArchive), false),
+			Entry("Archive in source and empty (KubeVirt by default) in target", string(cdiv1.DataVolumeArchive), "", false),
+		)
+
+		DescribeTable("Validation mechanism rejects or accepts the clone depending on the source and target size combination",
+			func(sourceSize, targetSize, expectedEvent string, explicitPvcRequest bool) {
+				dv := newCloneDataVolume("test-dv")
+				if !explicitPvcRequest {
+					dv.Spec.Storage = &cdiv1.StorageSpec{}
+					if targetSize != "" {
+						dv.Spec.Storage.Resources = corev1.VolumeResourceRequirements{
+							Requests: corev1.ResourceList{
+								corev1.ResourceStorage: resource.MustParse(targetSize),
+							},
+						}
+					}
+					dv.Spec.PVC = nil
+				} else {
+					dv.Spec.PVC.Resources.Requests[corev1.ResourceStorage] = resource.MustParse(targetSize)
+				}
+
+				srcPvc := CreatePvcInStorageClass("test", "default", &scName, nil, nil, corev1.ClaimBound)
+				srcPvc.Spec.VolumeMode = &BlockMode
+				srcPvc.Spec.Resources.Requests[corev1.ResourceStorage] = resource.MustParse(sourceSize)
+				storageProfile := createStorageProfile(scName, nil, FilesystemMode)
+				reconciler = createCloneReconciler(dv, srcPvc, storageProfile, sc)
+
+				syncRes := syncState(dv)
+				done, err := reconciler.validateCloneAndSourcePVC(syncRes, reconciler.log)
+				Expect(err).ToNot(HaveOccurred())
+				if expectedEvent != "" {
+					Expect(syncRes.phaseSync.event.message).To(ContainSubstring(expectedEvent))
+					Expect(done).To(BeFalse())
+				} else {
+					Expect(syncRes.phaseSync).To(BeNil())
+					Expect(done).To(BeTrue())
+				}
+			},
+			Entry("Explicit PVC request, target equal to source size should accept", "1Gi", "1Gi", "", true),
+			Entry("Explicit PVC request, target bigger then source size should accept", "1Gi", "2Gi", "", true),
+			Entry("Explicit PVC request, target smaller then source size should reject", "2Gi", "1Gi", "is smaller than the source", true),
+			Entry("Storage request, target equal to source size should accept", "1Gi", "1Gi", "", false),
+			Entry("Storage request, target bigger then source size should accept", "1Gi", "2Gi", "", false),
+			Entry("Storage request, target smaller then source size should reject", "2Gi", "1Gi", "is smaller than the source", false),
+			Entry("Storage request, no target size should accept", "1Gi", "", "", false),
+		)
+
+		It("should get event when target size is lower than source size", func() {
+			dv := newCloneDataVolume("test-dv")
+			storageProfile := createStorageProfile(scName, nil, FilesystemMode)
+			srcPvc := CreatePvcInStorageClass("test", "default", &scName, nil, nil, corev1.ClaimBound)
+			srcPvc.Spec.Resources.Requests[corev1.ResourceStorage] = resource.MustParse("2Gi")
+			reconciler = createCloneReconciler(dv, srcPvc, storageProfile, sc)
+			_, err := reconciler.Reconcile(context.TODO(), reconcile.Request{NamespacedName: types.NamespacedName{Name: "test-dv", Namespace: metav1.NamespaceDefault}})
+			Expect(err).ToNot(HaveOccurred())
+			dv = &cdiv1.DataVolume{}
+			err = reconciler.client.Get(context.TODO(), types.NamespacedName{Name: "test-dv", Namespace: metav1.NamespaceDefault}, dv)
+			Expect(err).ToNot(HaveOccurred())
+			event := <-reconciler.recorder.(*record.FakeRecorder).Events
+			Expect(event).To(ContainSubstring(CloneValidationFailed))
+		})
+
+	})
+
 	var _ = Describe("Clone without source", func() {
 		scName := "testsc"
 		sc := CreateStorageClassWithProvisioner(scName, map[string]string{
@@ -570,42 +802,6 @@ var _ = Describe("All DataVolume Tests", func() {
 			_, ok := pvc.Annotations[AnnCreatedForDataVolume]
 			Expect(ok).To(BeFalse())
 		})
-
-		DescribeTable("Validation mechanism rejects or accepts the clone depending on the contentType combination",
-			func(sourceContentType, targetContentType string, expectedResult bool) {
-				dv := newCloneDataVolume("test-dv")
-				dv.Spec.ContentType = cdiv1.DataVolumeContentType(targetContentType)
-				storageProfile := createStorageProfile(scName, nil, FilesystemMode)
-				reconciler = createCloneReconciler(dv, storageProfile, sc)
-
-				done, err := reconciler.validateCloneAndSourcePVC(syncState(dv), reconciler.log)
-				Expect(err).ToNot(HaveOccurred())
-				Expect(done).To(BeFalse())
-
-				// We create the source PVC after creating the clone
-				pvc := CreatePvcInStorageClass("test", metav1.NamespaceDefault, &scName, map[string]string{
-					AnnContentType: sourceContentType}, nil, corev1.ClaimBound)
-				err = reconciler.client.Create(context.TODO(), pvc)
-				Expect(err).ToNot(HaveOccurred())
-
-				done, err = reconciler.validateCloneAndSourcePVC(syncState(dv), reconciler.log)
-				Expect(done).To(Equal(expectedResult))
-				if expectedResult == false {
-					Expect(err).To(HaveOccurred())
-				} else {
-					Expect(err).ToNot(HaveOccurred())
-				}
-			},
-			Entry("Archive in source and target", string(cdiv1.DataVolumeArchive), string(cdiv1.DataVolumeArchive), true),
-			Entry("Archive in source and KubeVirt in target", string(cdiv1.DataVolumeArchive), string(cdiv1.DataVolumeKubeVirt), false),
-			Entry("KubeVirt in source and archive in target", string(cdiv1.DataVolumeKubeVirt), string(cdiv1.DataVolumeArchive), false),
-			Entry("KubeVirt in source and target", string(cdiv1.DataVolumeKubeVirt), string(cdiv1.DataVolumeKubeVirt), true),
-			Entry("Empty (KubeVirt by default) in source and target", "", "", true),
-			Entry("Empty (KubeVirt by default) in source and KubeVirt (explicit) in target", "", string(cdiv1.DataVolumeKubeVirt), true),
-			Entry("KubeVirt (explicit) in source and empty (KubeVirt by default) in target", string(cdiv1.DataVolumeKubeVirt), "", true),
-			Entry("Empty (kubeVirt by default) in source and archive in target", "", string(cdiv1.DataVolumeArchive), false),
-			Entry("Archive in source and empty (KubeVirt by default) in target", string(cdiv1.DataVolumeArchive), "", false),
-		)
 	})
 
 	var _ = Describe("Clone with empty storage size", func() {
@@ -804,7 +1000,7 @@ var _ = Describe("All DataVolume Tests", func() {
 			// Prepare the source PVC with the required annotations
 			pvc := CreatePvcInStorageClass("test", metav1.NamespaceDefault, &scName, annKubevirt, nil, corev1.ClaimBound)
 			pvc.Annotations[AnnVirtualImageSize] = "100" // Mock value
-			pvc.Annotations[AnnSourceCapacity] = string(pvc.Status.Capacity.Storage().String())
+			pvc.Annotations[AnnSourceCapacity] = pvc.Status.Capacity.Storage().String()
 			reconciler := createCloneReconciler(dv, pvc, storageProfile, sc)
 
 			// Get the expected value
@@ -954,7 +1150,7 @@ func newCloneDataVolumeWithPVCNS(name string, pvcNamespace string) *cdiv1.DataVo
 			PriorityClassName: "p0-clone",
 			PVC: &corev1.PersistentVolumeClaimSpec{
 				AccessModes: []corev1.PersistentVolumeAccessMode{corev1.ReadWriteOnce},
-				Resources: corev1.ResourceRequirements{
+				Resources: corev1.VolumeResourceRequirements{
 					Requests: corev1.ResourceList{
 						corev1.ResourceStorage: resource.MustParse("1G"),
 					},
