@@ -80,6 +80,7 @@ var _ = Describe("Datavolume controller reconcile loop", func() {
 		Expect(pvcPrime.GetAnnotations()[cc.AnnContentType]).To(Equal(contentType))
 		Expect(pvcPrime.GetAnnotations()[cc.AnnPreallocationRequested]).To(Equal(strconv.FormatBool(preallocation)))
 		Expect(pvcPrime.GetAnnotations()[cc.AnnPopulatorKind]).To(Equal(cdiv1.VolumeUploadSourceRef))
+		Expect(pvcPrime.GetLabels()[cc.LabelExcludeFromVeleroBackup]).To(Equal("true"))
 
 		_, err = r.Reconcile(context.TODO(), reconcile.Request{NamespacedName: types.NamespacedName{Name: "test-pvc", Namespace: metav1.NamespaceDefault}})
 		Expect(err).ToNot(HaveOccurred())
@@ -169,6 +170,8 @@ var _ = Describe("Datavolume controller reconcile loop", func() {
 		pvc.Spec.VolumeName = "test-pv"
 		cc.AddAnnotation(pvc, cc.AnnPodPhase, string(corev1.PodSucceeded))
 		pvcPrime := newUploadPopulatorPVC(PVCPrimeName(pvc))
+		pvc.Status = corev1.PersistentVolumeClaimStatus{Phase: corev1.ClaimBound}
+		pvcPrime.Status = corev1.PersistentVolumeClaimStatus{Phase: corev1.ClaimLost}
 
 		volumeUploadSourceCR := newUploadPopulatorCR("", false)
 		scName := "test-sc"
@@ -327,6 +330,7 @@ var _ = Describe("Datavolume controller reconcile loop", func() {
 		Expect(pvcPrime.GetAnnotations()[cc.AnnUploadRequest]).To(Equal(""))
 		Expect(pvcPrime.GetAnnotations()[cc.AnnPopulatorKind]).To(Equal(cdiv1.VolumeUploadSourceRef))
 		Expect(pvcPrime.Annotations[key]).To(Equal(expectedValue))
+		Expect(pvcPrime.GetLabels()[cc.LabelExcludeFromVeleroBackup]).To(Equal("true"))
 	},
 		Entry("No extra annotations", "", "", ""),
 		Entry("Invalid extra annotation is not passed", "invalid", "test", ""),
