@@ -85,8 +85,16 @@ type NbdKitLogWatcherVddk struct {
 }
 
 // createNbdKitWrapper starts nbdkit and returns a process handle for further management
-func createNbdKitWrapper(vmware *VMwareClient, diskFileName string) (*NbdKitWrapper, error) {
-	n, err := image.NewNbdkitVddk(nbdPidFile, nbdUnixSocket, vmware.url.Host, vmware.username, vmware.password, vmware.thumbprint, vmware.moref)
+func createNbdKitWrapper(vmware *VMwareClient, diskFileName, snapshot string) (*NbdKitWrapper, error) {
+	args := image.NbdKitVddkPluginArgs{
+		Server:     vmware.url.Host,
+		Username:   vmware.username,
+		Password:   vmware.password,
+		Thumbprint: vmware.thumbprint,
+		Moref:      vmware.moref,
+		Snapshot:   snapshot,
+	}
+	n, err := image.NewNbdkitVddk(nbdPidFile, nbdUnixSocket, args)
 	if err != nil {
 		klog.Errorf("Error validating nbdkit plugins: %v", err)
 		return nil, err
@@ -429,25 +437,34 @@ func (vmware *VMwareClient) FindDiskFromName(fileName string) (*types.VirtualDis
 
 // FindSnapshotDiskName finds the name of the given disk at the time the snapshot was taken
 func (vmware *VMwareClient) FindSnapshotDiskName(snapshotRef *types.ManagedObjectReference, diskID string) (string, error) {
+	disk, err := vmware.FindSnapshotDisk(snapshotRef, diskID)
+	if err != nil {
+		return "", err
+	}
+	device := disk.GetVirtualDevice()
+	backing := device.Backing.(types.BaseVirtualDeviceFileBackingInfo)
+	info := backing.GetVirtualDeviceFileBackingInfo()
+	return info.FileName, nil
+}
+
+// FindSnapshotDisk finds the name of the given disk at the time the snapshot was taken
+func (vmware *VMwareClient) FindSnapshotDisk(snapshotRef *types.ManagedObjectReference, diskID string) (*types.VirtualDisk, error) {
 	var snapshot mo.VirtualMachineSnapshot
 	err := vmware.vm.Properties(vmware.context, *snapshotRef, []string{"config.hardware.device"}, &snapshot)
 	if err != nil {
 		klog.Errorf("Unable to get snapshot properties: %v", err)
-		return "", err
+		return nil, err
 	}
 
 	for _, device := range snapshot.Config.Hardware.Device {
 		switch disk := device.(type) {
 		case *types.VirtualDisk:
 			if disk.DiskObjectId == diskID {
-				device := disk.GetVirtualDevice()
-				backing := device.Backing.(types.BaseVirtualDeviceFileBackingInfo)
-				info := backing.GetVirtualDeviceFileBackingInfo()
-				return info.FileName, nil
+				return disk, nil
 			}
 		}
 	}
-	return "", fmt.Errorf("Could not find disk image with ID %s in snapshot %s", diskID, snapshotRef.Value)
+	return nil, fmt.Errorf("Could not find disk image with ID %s in snapshot %s", diskID, snapshotRef.Value)
 }
 
 // FindVM takes the UUID of the VM to migrate and finds its MOref
@@ -847,22 +864,46 @@ func createVddkDataSource(endpoint string, accessKey string, secKey string, thum
 	// then get the list of changed blocks from VMware for a delta copy.
 	var changed *types.DiskChangeInfo
 	if currentSnapshot != nil && previousCheckpoint != "" {
+		disk, err := vmware.FindSnapshotDisk(currentSnapshot, backingFileObject.DiskObjectId)
+		if err != nil {
+			klog.Errorf("Could not find matching disk in current snapshot: %v", err)
+			return nil, err
+		}
+		// QueryChangedDiskAreas needs to be called multiple times to get all possible disk changes.
+		// Experimentation shows it returns maximally 2000 changed blocks. If the disk has more than
+		// 2000 changed blocks we need to query the next chunk of the blocks starting from previous.
+		// Loop until QueryChangedDiskAreas starts returning zero-length block lists.
+		changed = &types.DiskChangeInfo{}
 		// Check if this is a snapshot or a change ID, and query disk areas as appropriate.
 		// Change IDs look like: 52 de c0 d9 b9 43 9d 10-61 d5 4c 1b e9 7b 65 63/81
 		changeIDPattern := `([0-9a-fA-F]{2}\s?)*-([0-9a-fA-F]{2}\s?)*\/([0-9a-fA-F]*)`
 		if matched, _ := regexp.MatchString(changeIDPattern, previousCheckpoint); matched {
-			request := types.QueryChangedDiskAreas{
-				ChangeId:    previousCheckpoint,
-				DeviceKey:   backingFileObject.Key,
-				Snapshot:    currentSnapshot,
-				StartOffset: 0,
-				This:        vmware.vm.Reference(),
+			for {
+				klog.Infof("Querying changed disk areas at offset %d", changed.Length)
+				request := types.QueryChangedDiskAreas{
+					ChangeId:    previousCheckpoint,
+					DeviceKey:   backingFileObject.Key,
+					Snapshot:    currentSnapshot,
+					StartOffset: changed.Length,
+					This:        vmware.vm.Reference(),
+				}
+				response, err := QueryChangedDiskAreas(vmware.context, vmware.vm.Client(), &request)
+				if err != nil {
+					klog.Errorf("Failed to query changed areas: %s", err)
+					return nil, err
+				}
+				klog.Infof("%d changed areas reported at offset %d with data length %d", len(response.Returnval.ChangedArea), changed.Length, response.Returnval.Length)
+				if len(response.Returnval.ChangedArea) == 0 { // No more changes
+					break
+				}
+				changed.ChangedArea = append(changed.ChangedArea, response.Returnval.ChangedArea...)
+				changed.Length += response.Returnval.Length
+				// The start offset should not be the size of the disk otherwise the QueryChangedDiskAreas will fail
+				if changed.Length >= disk.CapacityInBytes {
+					klog.Infof("the offset %d is greater or equal to disk capacity %d", changed.Length, disk.CapacityInBytes)
+					break
+				}
 			}
-			response, err := QueryChangedDiskAreas(vmware.context, vmware.vm.Client(), &request)
-			if err != nil {
-				return nil, err
-			}
-			changed = &response.Returnval
 		} else { // Previous checkpoint is a snapshot
 			previousSnapshot, err := vmware.vm.FindSnapshot(vmware.context, previousCheckpoint)
 			if err != nil {
@@ -870,12 +911,25 @@ func createVddkDataSource(endpoint string, accessKey string, secKey string, thum
 				return nil, err
 			}
 			if previousSnapshot != nil {
-				changedAreas, err := vmware.vm.QueryChangedDiskAreas(vmware.context, previousSnapshot, currentSnapshot, backingFileObject, 0)
-				if err != nil {
-					klog.Errorf("Unable to query changed areas: %s", err)
-					return nil, err
+				for {
+					klog.Infof("Querying changed disk areas at offset %d", changed.Length)
+					changedAreas, err := vmware.vm.QueryChangedDiskAreas(vmware.context, previousSnapshot, currentSnapshot, backingFileObject, changed.Length)
+					if err != nil {
+						klog.Errorf("Unable to query changed areas: %s", err)
+						return nil, err
+					}
+					klog.Infof("%d changed areas reported at offset %d with data length %d", len(changedAreas.ChangedArea), changed.Length, changedAreas.Length)
+					if len(changedAreas.ChangedArea) == 0 {
+						break
+					}
+					changed.ChangedArea = append(changed.ChangedArea, changedAreas.ChangedArea...)
+					changed.Length += changedAreas.Length
+					// The start offset should not be the size of the disk otherwise the QueryChangedDiskAreas will fail
+					if changed.Length >= disk.CapacityInBytes {
+						klog.Infof("the offset %d is greater or equal to disk capacity %d", changed.Length, disk.CapacityInBytes)
+						break
+					}
 				}
-				changed = &changedAreas
 			}
 		}
 	}
@@ -891,7 +945,7 @@ func createVddkDataSource(endpoint string, accessKey string, secKey string, thum
 		}
 		klog.Infof("Set disk file name from current snapshot: %s", diskFileName)
 	}
-	nbdkit, err := newNbdKitWrapper(vmware, diskFileName)
+	nbdkit, err := newNbdKitWrapper(vmware, diskFileName, currentCheckpoint)
 	if err != nil {
 		klog.Errorf("Unable to start nbdkit: %v", err)
 		return nil, err
@@ -1078,5 +1132,10 @@ func (vs *VDDKDataSource) TransferFile(fileName string) (ProcessingPhase, error)
 		}
 	}
 
+	if vs.PreviousSnapshot != "" {
+		// Don't resize when applying snapshot deltas as the resize has already happened
+		// when the first snapshot was imported.
+		return ProcessingPhaseComplete, nil
+	}
 	return ProcessingPhaseResize, nil
 }
