@@ -1,14 +1,18 @@
 package cdicontroller
 
 import (
-	"github.com/prometheus/client_golang/prometheus"
-
 	"github.com/machadovilaca/operator-observability/pkg/operatormetrics"
+	"github.com/prometheus/client_golang/prometheus"
+	ioprometheusclient "github.com/prometheus/client_model/go"
 )
 
 const (
-	prometheusNsLabel       = "ns"
-	prometheusCronNameLabel = "cron_name"
+	// PrometheusCronNsLabel labels the DataImportCron namespace
+	PrometheusCronNsLabel = "ns"
+	// PrometheusCronNameLabel labels the DataImportCron name
+	PrometheusCronNameLabel = "cron_name"
+	// PrometheusCronPendingLabel labels whether the DataImportCron import DataVolume is pending for default storage class
+	PrometheusCronPendingLabel = "pending"
 )
 
 var (
@@ -21,7 +25,7 @@ var (
 			Name: "kubevirt_cdi_dataimportcron_outdated",
 			Help: "DataImportCron has an outdated import",
 		},
-		[]string{prometheusNsLabel, prometheusCronNameLabel},
+		[]string{PrometheusCronNsLabel, PrometheusCronNameLabel, PrometheusCronPendingLabel},
 	)
 )
 
@@ -36,6 +40,13 @@ func SetDataImportCronOutdated(labels prometheus.Labels, isOutdated bool) {
 	dataImportCronOutdated.With(labels).Set(outdatedValue)
 }
 
+// GetDataImportCronOutdated returns the dataImportCronOutdated value
+func GetDataImportCronOutdated(labels prometheus.Labels) float64 {
+	dto := &ioprometheusclient.Metric{}
+	_ = dataImportCronOutdated.With(labels).Write(dto)
+	return dto.Gauge.GetValue()
+}
+
 // DeleteDataImportCronOutdated deletes metrics by their labels, and return the number of deleted metrics
 func DeleteDataImportCronOutdated(labels prometheus.Labels) int {
 	return dataImportCronOutdated.DeletePartialMatch(labels)
