@@ -11,7 +11,6 @@ import (
 	. "github.com/onsi/ginkgo/v2"
 	. "github.com/onsi/gomega"
 
-	ocpconfigv1 "github.com/openshift/api/config/v1"
 	apiequality "k8s.io/apimachinery/pkg/api/equality"
 	metav1 "k8s.io/apimachinery/pkg/apis/meta/v1"
 
@@ -23,7 +22,7 @@ import (
 
 const (
 	cdiDeploymentPodPrefix  = "cdi-deployment-"
-	cdiApiServerPodPrefix   = "cdi-apiserver-"
+	cdiAPIServerPodPrefix   = "cdi-apiserver-"
 	cdiUploadProxyPodPrefix = "cdi-uploadproxy-"
 
 	pollingInterval = 2 * time.Second
@@ -52,12 +51,12 @@ var _ = Describe("cdi-apiserver tests", Serial, func() {
 
 			client := &http.Client{
 				Transport: &http.Transport{
-					TLSClientConfig: &tls.Config{InsecureSkipVerify: true},
+					TLSClientConfig: &tls.Config{InsecureSkipVerify: true}, //nolint: gosec // It's not production codeº
 				},
 			}
 
 			Eventually(func() error {
-				req, err := http.NewRequest("GET", url, nil)
+				req, err := http.NewRequest(http.MethodGet, url, nil)
 				Expect(err).ToNot(HaveOccurred())
 
 				resp, err := client.Do(req)
@@ -105,11 +104,11 @@ var _ = Describe("cdi-apiserver tests", Serial, func() {
 
 		It("[test_id:9062]should fail reaching server when TLS profile requires minimal TLS version higher than our client's", func() {
 			Expect(utils.UpdateCDIConfig(f.CrClient, func(config *cdiv1.CDIConfigSpec) {
-				config.TLSSecurityProfile = &ocpconfigv1.TLSSecurityProfile{
+				config.TLSSecurityProfile = &cdiv1.TLSSecurityProfile{
 					// Modern profile requires TLS 1.3
 					// https://wiki.mozilla.org/Security/Server_Side_TLS#Modern_compatibility
-					Type:   ocpconfigv1.TLSProfileModernType,
-					Modern: &ocpconfigv1.ModernTLSProfile{},
+					Type:   cdiv1.TLSProfileModernType,
+					Modern: &cdiv1.ModernTLSProfile{},
 				}
 			})).To(Succeed())
 
@@ -124,14 +123,14 @@ var _ = Describe("cdi-apiserver tests", Serial, func() {
 			client := &http.Client{
 				Transport: &http.Transport{
 					TLSClientConfig: &tls.Config{
-						InsecureSkipVerify: true,
+						InsecureSkipVerify: true, //nolint: gosec // It's not production code
 						MinVersion:         tls.VersionTLS12,
 						MaxVersion:         tls.VersionTLS12,
 					},
 				},
 			}
 			requestFunc := func() string {
-				req, err := http.NewRequest("GET", url, nil)
+				req, err := http.NewRequest(http.MethodGet, url, nil)
 				if err != nil {
 					return err.Error()
 				}
@@ -148,11 +147,11 @@ var _ = Describe("cdi-apiserver tests", Serial, func() {
 
 			// Change to intermediate, which is fine with 1.2, expect success
 			err = utils.UpdateCDIConfig(f.CrClient, func(config *cdiv1.CDIConfigSpec) {
-				config.TLSSecurityProfile = &ocpconfigv1.TLSSecurityProfile{
+				config.TLSSecurityProfile = &cdiv1.TLSSecurityProfile{
 					// Intermediate profile requires TLS 1.2
 					// https://wiki.mozilla.org/Security/Server_Side_TLS#Intermediate_compatibility_.28recommended.29
-					Type:         ocpconfigv1.TLSProfileIntermediateType,
-					Intermediate: &ocpconfigv1.IntermediateTLSProfile{},
+					Type:         cdiv1.TLSProfileIntermediateType,
+					Intermediate: &cdiv1.IntermediateTLSProfile{},
 				}
 			})
 			Expect(err).ToNot(HaveOccurred())
