@@ -8,9 +8,11 @@ import (
 	"strings"
 	"time"
 
-	"github.com/docker/go-units"
 	"github.com/onsi/ginkgo/v2"
 	"github.com/onsi/gomega"
+
+	"github.com/docker/go-units"
+
 	k8sv1 "k8s.io/api/core/v1"
 	apierrs "k8s.io/apimachinery/pkg/api/errors"
 	"k8s.io/apimachinery/pkg/api/resource"
@@ -30,7 +32,7 @@ func (f *Framework) CreatePVCFromDefinition(def *k8sv1.PersistentVolumeClaim) (*
 	return utils.CreatePVCFromDefinition(f.K8sClient, f.Namespace.Name, def)
 }
 
-// CreateBoundPVCFromDefinition is a wrapper around utils.CreatePVCFromDefinition that also force binds pvc on
+// CreateBoundPVCFromDefinition is a wrapper around utils.CreatePVCFromDefinition that also force binds pvc
 // on WaitForFirstConsumer storage class by executing f.ForceBindIfWaitForFirstConsumer(pvc)
 func (f *Framework) CreateBoundPVCFromDefinition(def *k8sv1.PersistentVolumeClaim) *k8sv1.PersistentVolumeClaim {
 	pvc, err := utils.CreatePVCFromDefinition(f.K8sClient, f.Namespace.Name, def)
@@ -250,7 +252,7 @@ func (f *Framework) GetMD5(namespace *k8sv1.Namespace, pvc *k8sv1.PersistentVolu
 		return "", err
 	}
 
-	fmt.Fprintf(ginkgo.GinkgoWriter, "INFO: md5sum found %s\n", string(output[:32]))
+	fmt.Fprintf(ginkgo.GinkgoWriter, "INFO: md5sum found %s\n", output[:32])
 	// Don't delete pod, other verification might happen.
 	return output[:32], nil
 }
@@ -277,7 +279,7 @@ func (f *Framework) VerifyBlankDisk(namespace *k8sv1.Namespace, pvc *k8sv1.Persi
 
 	return f.verifyInPod(namespace, pvc, cmd, func(output, stderr string) (bool, error) {
 		fmt.Fprintf(ginkgo.GinkgoWriter, "INFO: empty file check %s\n", output)
-		return strings.Compare("All zeros", string(output)) == 0, nil
+		return strings.Compare("All zeros", output) == 0, nil
 	})
 }
 
@@ -388,7 +390,7 @@ func (f *Framework) VerifyTargetPVCArchiveContent(namespace *k8sv1.Namespace, pv
 	cmd := "ls -I lost+found " + utils.DefaultPvcMountPath + " | wc -l"
 
 	return f.verifyInPod(namespace, pvc, cmd, func(output, stderr string) (bool, error) {
-		fmt.Fprintf(ginkgo.GinkgoWriter, "INFO: file count found %s\n", string(output))
+		fmt.Fprintf(ginkgo.GinkgoWriter, "INFO: file count found %s\n", output)
 		return strings.Compare(count, output) == 0, nil
 	})
 }
@@ -536,7 +538,7 @@ func (f *Framework) GetImageInfo(namespace *k8sv1.Namespace, pvc *k8sv1.Persiste
 
 		err := json.Unmarshal([]byte(output), info)
 		if err != nil {
-			klog.Errorf("Invalid JSON:\n%s\n", string(output))
+			klog.Errorf("Invalid JSON:\n%s\n", output)
 			return false, err
 		}
 
@@ -555,7 +557,7 @@ func (f *Framework) GetImageContentSize(namespace *k8sv1.Namespace, pvc *k8sv1.P
 
 		size, err := strconv.ParseInt(output, 10, 64)
 		if err != nil {
-			klog.Errorf("Invalid image content size:\n%s\n", string(output))
+			klog.Errorf("Invalid image content size:\n%s\n", output)
 			return false, err
 		}
 		*imageSize = size
